@@ -5,4 +5,6 @@ class childcare_expenses(Variable):
     value_type = float
     entity = SPMUnit
     label = "Child care expenses"
+    documentation = "Out of pocket spending on childcare"
     definition_period = YEAR
+    unit = USD
