@@ -11,10 +11,12 @@ class lifeline(Variable):
     reference = "https://www.law.cornell.edu/cfr/text/47/54.403"
 
     def formula(spm_unit, period, parameters):
+        # NB: Only one Lifeline benefit is available per SPM unit, per:
+        # https://www.law.cornell.edu/cfr/text/47/54.409#c
         max_amount = parameters(period).fcc.lifeline.amount * 12
         phone_broadband_cost = add(
             spm_unit, period, ["phone_cost", "broadband_cost"]
         )
         amount_if_eligible = min_(phone_broadband_cost, max_amount)
         eligible = spm_unit("is_lifeline_eligible", period)
-        return where(eligible, amount_if_eligible, 0)
+        return eligible * amount_if_eligible
